@@ -1,9 +1,11 @@
 
 from datetime import datetime
 import sys
+import logging
 
 import pandas as pd
 from pandas_datareader import data
+from pandas_datareader._utils import RemoteDataError
 
 
 def get_yahoofinance_data(symbol, startdate, enddate):
@@ -14,9 +16,8 @@ def get_yahoofinance_data(symbol, startdate, enddate):
             start=datetime.strptime(startdate, '%Y-%m-%d'),
             end=datetime.strptime(enddate, '%Y-%m-%d')
         )
-    except KeyError as e:
-        print('Symbol {} does not exist between {} and {}.'.format(symbol, startdate, enddate),
-              file=sys.stderr)
+    except (KeyError, RemoteDataError) as e:
+        logging.warning('Symbol {} does not exist between {} and {}.'.format(symbol, startdate, enddate))
         return pd.DataFrame({
             'TimeStamp': [],
             'High': [],
